nedit(1)

NEdit - Text Editor

As shipped in IRIX 6.5.19. Added in IRIX 6.5.19.

NAME
     NEdit - Text Editor

SYNOPSYS
     nedit [-read] [-create] [-line n | +n] [-server] [-do command] [-tags
     file] [-tabs n] [-wrap] [-nowrap] [-autowrap] [-autoindent]
     [-noautoindent] [-autosave] [-noautosave] [-lm languagemode] [-rows n]
     [-columns n] [-font font] [-geometry geometry] [-iconic] [-noiconic]
     [-display [host]:server[.screen]] [-xrm resourcestring] [-svrname name]
     [-import file] [-background color] [-foreground color] [-V] [-version]
     [file...]

DESCRIPTION
     NEdit is a standard GUI (Graphical User Interface) style text editor for
     programs and plain-text files. It provides mouse based editing and a
     streamlined editing style, based on popular Macintosh and MS Windows
     editors, for users of X workstations and X terminals.

OPTIONS
     -read
         Open the file read-only regardless of the actual file protection.

     -create
         Don't warn about file creation when a file doesn't exist.

     -line n, +n
         Go to line number n.

     -server
         Designate this session as an NEdit server, for processing commands
         from the nc(1) program. nc(1) can be used to interface NEdit to code
         development environments, mailers, etc., or just as a quick way to
         open files from the shell command line without starting a new NEdit
         session.

     -do command
         Execute an NEdit macro or action. On each file following the -do
         argument on the command line. -do is particularly useful from the
         nc(1) program, where `nc -do' can remotely execute commands in an
         nedit -server session.

     -tags file
         Load a file of directions for finding definitions of program
         subroutines and data objects. The file must be of the format
         generated by Exuberant Ctags, or the standard Unix ctags(1) command.

     -tabs n
         Set tab stops every n characters.

     -wrap, -nowrap
         Wrap long lines at the right edge of the window rather than
         continuing them past it. (Continuous Wrap mode)
     -autowrap, -noautowrap
         Wrap long lines when the cursor reaches the right edge of the window
         by inserting newlines at word boundaries. (Auto Newline Wrap mode)

     -autoindent, -noautoindent
         Maintain a running indent.

     -autosave, -noautosave
         Maintain a backup copy of the file being edited under the name
         ~filename (on Unix) or _filename (on VMS).

     -lm languagemode
         Initial language mode used for editing succeeding files.

     -rows n
         Default height in characters for an editing window.

     -columns n
         Default width in characters for an editing window.

     -font font, -fn font
         Font for text being edited. Font for menus and dialogs can be set
         with -xrm "*fontList:font".

     -geometry geometry, -g geometry
         The initial size and/or location of editor windows. The argument
         geometry has the form:

           [<width>x<height>][+|-][<xoffset>[+|-]<yoffset>]

         where `<width>' and `<height>' are the desired width and height of
         the window, and `<xoffset>' and `<yoffset>' are the distance from the
         edge of the screen to the window, + for top or left, - for bottom or
         right. -geometry can be specified for individual files on the command
         line.

     -iconic, -noiconic
         Initial window state for succeeding files.

     -display [host]:server[.screen]
         The name of the X server to use. host specifies the machine, server
         specifies the display server number, and screen specifies the screen
         number.  host or screen can be omitted and default to the local
         machine, and screen 0.

     -background color, -bg color
         Background color. The background color for text can be set separately
         with -xrm "nedit*text.background: color".

     -foreground color, -fg color
         Foreground color. The foreground color for text can be set separately
         with -xrm "nedit*text.foreground: color".
     -xrm resourcestring
         Set the value of an X resource to override a default value.

     -svrname name
         When starting nedit in server mode, name the server, such that it
         responds to requests only when nc(1) is given a corresponding
         -svrname argument.  By naming servers, you can run several
         simultaneously, and direct files and commands specifically to any
         one.

     -import file
         Loads an additional preferences file on top of the existing defaults
         saved in your .nedit file.  To incorporate macros, language modes,
         and highlight patterns and styles written by other users, run nedit
         with -import <file>, then re-save your .nedit file with Preferences-
         >Save Defaults.

     -V, -version
         Prints version and build information, to be mentioned when reporting
         bugs and problems. Also prints credits and license information.

ENVIRONMENT
     DISPLAY
         NEdit requires an X-based workstation or X-Terminal. If you have used
         telnet or rlogin to access the host Unix system, set the Unix
         environment variable for your display:

             % setenv DISPLAY devicename:0


FILES
     NEdit stores a few files in a user's home directory:

     .nedit
         The general configuration file. Do not edit this file by hand.

     .neditmacro
         A file that can contain a number of macro statements and subroutines.
         The statements will be executed when a NEdit server starts, the
         subroutines will be loaded for later reference.

     .neditdb
         The list of recently opened files. Do not edit this file by hand.

NOTES
     For more information see NEdit's online help, or nedit.doc in the NEdit
     distribution kit.

     NEdit sources, executables, additional documentation, and contributed
     software are available from the NEdit web site at http://nedit.org.

SEE ALSO
     nc(1), X(1), mwm(1), vi(1), emacs(1), ctags(1)

AUTHORS
     NEdit was written by Mark Edel, Joy Kyriakopulos, Christopher Conrad, Jim
     Clark, Arnulfo Zepeda-Navratil, Suresh Ravoor, Tony Balinski, Max
     Vohlken, Yunliang Yu, Donna Reid, Arne Forlie, Eddy De Greef, Steve
     LoBasso, Alexander Mai, Scott Tringali, and Thorsten Haude.

     The regular expression matching routines used in NEdit are adapted (with
     permission) from original code written by Henry Spencer at the University
     of Toronto.

     Syntax highlighting patterns and smart indent macros were contributed by:
     Simon T. MacDonald,  Maurice Leysens, Matt Majka, Alfred Smeenk, Alain
     Fargues, Christopher Conrad, Scott Markinson, Konrad Bernloehr, Ivan
     Herman, Patrice Venant, Christian Denat, Philippe Couton, Max Vohlken,
     Markus Schwarzenberg, Himanshu Gohel, Steven C. Kapp, Michael Turomsha,
     John Fieber, Chris Ross, Nathaniel Gray, Joachim Lous, Mike Duigou, Seak
     Teng-Fong, Joor Loohuis, Mark Jones, and Niek van den Berg.

COPYRIGHT
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
     Free Software Foundation; either version 2 of the License, or (at your
     option) any later version.

     This program is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
     Public License in the Help section "Distribution Policy" for more
     details.